@@ -18,7 +18,7 @@ using namespace Rcpp;
 // [[Rcpp::export]]
 double epanechnikov(double x){
   double bound = std::sqrt(5.0);
-  double y = 3*(5-(x*x))/(2*std::sqrt(5.0))*(x>(-1.0*bound))*(x<(1.0*bound));
+  double y = 3.0*(5.0-(x*x))/(20.0*std::sqrt(5.0))*(x>(-1.0*bound))*(x<(1.0*bound));
   return y;
 }
 
